@@ -18,10 +18,10 @@ class DKConnection():
         if "\n" in r.text or "\r" in r.text:
             logger.error("Error: Platform returned invalid token." % (kitchen, recipe, variation))
         self.token = r.text
-        self.headers =  {'content-type': 'application/json', 'authorization': 'bearer ' + self.token}
+        self.headers =  {'content-type': 'application/json', 'authorization': 'Bearer ' + self.token}
 
     def createOrder(self, kitchen, recipe, variation, overrides={}, retries=1):
-        headers = {'content-type': 'application/json', 'authorization': 'bearer ' + self.token}
+        headers = {'content-type': 'application/json', 'authorization': 'Bearer ' + self.token}
         url = 'https://%s/v2/order/create/%s/%s/%s' % (self.hostname, kitchen, recipe, variation)
         payload = {'parameters': overrides, "schedule" : "now"}
         response = requests.put(url, headers=headers, data=json.dumps(payload))
@@ -35,6 +35,8 @@ class DKConnection():
     def safeCreateOrder(self, kitchen, recipe, variation, overrides={}, wait_time=10, timeout=50000, test_level=""):
         response = self.createOrder(kitchen, recipe, variation, overrides=overrides)
         if response.status_code != 200:
+            logger.error("%s" % (str(self.headers))
+            logger.error("Response %d: %s" % (response.status_code, response.text))
             logger.error("Error Starting Order %s %s %s." % (kitchen, recipe, variation))
             raise DKOrderStartException
         order = json.loads(response.text)
